import React from "react";
import {
  IMenuItem,
  ISocialMediaItem,
  IPolicy,
  ISupportedBy,
} from "@interfaces/IFooter";
import { POLICY } from "@common/constants";
import { Link } from "@components/Link";
import { SocialMediaIcons } from "@components/SocialMediaIcons";

interface FooterProps {
  menu: IMenuItem[];
  copyright: string;
  policyLinks?: IPolicy[];
  socialMedia?: ISocialMediaItem[];
  supportedBy?: ISupportedBy[];
  newsletterSlot?: React.ReactNode;
}

export const Footer: React.FC<FooterProps> = ({
  menu,
  copyright,
  policyLinks,
  socialMedia,
  supportedBy,
  newsletterSlot,
}) => {
  return (
    <footer className="bg-grey-900 py-16">
      <div className="container">
        <Menu menu={menu} />
        <NewsletterAndSocialMedia
          socialMedia={socialMedia}
          newsletterSlot={newsletterSlot}
        />
        {supportedBy && (
          <SupportedBy title="Gefördert durch" items={supportedBy} />
        )}
        <BottomLine copyright={copyright} policyLinks={policyLinks} />
      </div>
    </footer>
  );
};

interface SupportedByProps {
  items?: ISupportedBy[];
  title: string;
}

const SupportedBy: React.FC<SupportedByProps> = ({ items, title }) => {
  return (
    <div className="mt-5">
      <h4 className="font-normal text-sm text-grey-400">{title}</h4>
      {items && (
        <div className="flex flex-col sm:flex-row gap-5 mt-5 items-center">
          {items.map((item, index) => {
            return item.href ? (
              // eslint-disable-next-line react/jsx-no-target-blank
              <a key={index} target="_blank" rel="noopener" href={item.href}>
                <img src={item.img} alt={item.alt} className="w-60 h-60" />
              </a>
            ) : (
              <img key={index} src={item.img} alt={item.alt} className="w-60 h-60" />
            );
          })}
        </div>
      )}
    </div>
  );
};

interface MenuProps {
  menu: IMenuItem[];
}

const Menu: React.FC<MenuProps> = ({ menu }) => {
  return (
    <div className="w-full flex flex-col md:flex-row md:flex-wrap font-plex">
      {menu.map((item, index) => (
        <SubMenu key={index} submenu={item} />
      ))}
    </div>
  );
};

interface ISubMenu {
  submenu: IMenuItem;
}

const SubMenu: React.FC<ISubMenu> = ({ submenu }) => {
  return (
    <div className="w-full md:w-1/3 lg:w-1/5 md:mt-0 mb-16 md:mb-8 lg:mb-0">
      {submenu.children && submenu.children.length > 0 ? (
        <h5 className="w-fit text-sm leading-5 font-semibold text-grey-50">
          {submenu.title}
        </h5>
      ) : (
        <Link
          to={submenu.target}
          className="w-fit text-sm leading-5 font-semibold text-grey-50"
        >
          {submenu.title}
        </Link>
      )}
      {submenu.children && submenu.children.length > 0 && (
        <ul>
          {submenu.children.map((child, index) => (
            <li key={index} className="w-fit mt-5">
              <a
                href={child.target}
                className="text-sm leading-5 font-normal text-grey-400"
              >
                {child.title}
              </a>
            </li>
          ))}
        </ul>
      )}
    </div>
  );
};

interface NewsletterAndSocialMediaProps {
  socialMedia?: ISocialMediaItem[];
  newsletterSlot?: React.ReactNode;
}

const NewsletterAndSocialMedia: React.FC<NewsletterAndSocialMediaProps> = ({
  socialMedia,
  newsletterSlot = <NewsletterFormExample />,
}) => {
  return (
    <div className="w-full flex flex-col md:flex-row md:justify-between mt-0 md:mt-12">
      <SocialMediaIcons grow icons={socialMedia} id="social-footer" className="mr-4 order-2 flex-1 lg:order-1 mt-16 md:mt-0 md:max-w-sm" light/>
      {newsletterSlot && (
        <div className="w-full md:w-3/5 lg:w-1/2 xl:w-[34%] 2xl:w-[28%] order-1 md:order-2">
          {newsletterSlot}
        </div>
      )}
    </div>
  );
};

interface BottomLineProps {
  copyright: string;
  policyLinks?: IPolicy[];
}

const BottomLine: React.FC<BottomLineProps> = ({
  copyright,
  policyLinks = POLICY,
}) => {
  return (
    <div className="w-full flex flex-col lg:flex-row md:justify-between mt-16 md:mt-10">
      {Boolean(policyLinks.length) && (
        <ul className="font-plex text-sm leading-5 font-normal text-grey-400 text-center lg:text-left">
          {policyLinks.map((policy, index) => (
            <li
              key={index}
              className={`inline-block ${
                index !== policyLinks.length - 1 ? "border-r" : ""
              } ${index === 0 ? "pr-4" : "px-4"} `}
            >
              <a href={policy.href}>{policy.title}</a>
            </li>
          ))}
        </ul>
      )}
      <div className="text-center lg:text-left mt-6 lg:mt-0">
        <span className="font-plex text-sm leading-5 font-normal text-grey-400">
          {copyright}
        </span>
      </div>
    </div>
  );
};

const NewsletterFormExample: React.FC = () => (
  <>
    <h5 className="font-karla text-base leading-6 font-semibold tracking-wide uppercase text-pearl-200">
      Join our Newsletter 🤙
    </h5>
    <div className="w-full mt-4 flex flex-col md:flex-row">
      <input
        className="w-full md:w-[72%] px-3 py-2 rounded font-plex text-base leading-6 font-normal outline-0"
        placeholder="Enter your email"
      />
      <button className="bg-white md:flex-1 py-2 rounded font-plex text-base leading-6 font-medium mt-3 md:mt-0 md:ml-4">
        Subscribe
      </button>
    </div>
  </>
);
