import React, { useState, Fragment } from "react";
import { Earth } from "@carbon/icons-react";

interface LanguageSelectorProps {
  // Mobile menu overlay when Hamburger button is clicked
  isMobileOpen?: boolean;
  // Show options horizontally instead of "dropdown on hover"
  horizontal?: boolean;
  languages: Array<string>;
  selectedLanguage?: string;
  onChangeLanguage?: (newLanguage: string) => void;
  faded?: boolean;
  onHover?: (value: boolean) => void;
  // Use light primary colors (e.g. for use with dark backgrounds)
  light?: boolean;
}

export const LanguageSelector: React.FC<LanguageSelectorProps> = ({
  horizontal,
  selectedLanguage,
  languages,
  onChangeLanguage,
  onHover,
  isMobileOpen,
  faded,
  light,
}) => {
  // Selector is open – options are visible
  const [isOpen, setIsOpen] = useState(false);

  const getIconColor = (
    isMobileOpen?: boolean,
    faded?: boolean,
    light?: boolean,
  ) => {
    if (isMobileOpen) return "text-white";
    if (!faded) {
      return light
        ? "text-grey-900 sm:text-white lg:text-grey-900"
        : "text-grey-900";
    }
    if (faded) {
      return "text-grey-400 hover:text-grey-900";
    }
  };

  const getLocaleColor = (
    isMobileOpen?: boolean,
    light?: boolean,
    isActive?: boolean,
    horizontal?: boolean,
  ) => {
    // Mobile overlay (always blue/white)
    if (isMobileOpen) return "text-white";

    // Mobile
    if (horizontal) {
      if (light)
        return isActive ? "text-grey-900 sm:text-white" : "text-grey-400";
      if (!light) return isActive ? "text-grey-900" : "text-grey-400";
    } else {
      // Desktop
      if (light)
        return isActive ? "text-grey-900 sm:text-white" : "text-grey-400";
      if (!light) return isActive ? "text-white" : "text-grey-400";
    }
  };

  const handleLanguageClick = (language: string) => {
    if (language === selectedLanguage) return;
    setIsOpen(false);
    onChangeLanguage && onChangeLanguage(language);
  };

  const iconColor = getIconColor(isMobileOpen, faded, light);

  return languages ? (
    <Fragment>
      {horizontal ? (
        <div className="relative lg:hidden flex items-center">
          <button
            onClick={() => setIsOpen(!isOpen)}
            className={`order-2 z-10 ${iconColor || ""}`}
          >
            <Earth size={24} />
          </button>
          <div
            className={`absolute right-0 opacity-0 ${
              isOpen ? "!right-full opacity-100" : ""
            } order-1 flex px-4 font-plex text-sm leading-5 font-semibold transition-all ease-in duration-50`}
          >
            {languages &&
              languages.map((language) => {
                const isActive = language === selectedLanguage;
                const classes = getLocaleColor(
                  isMobileOpen,
                  light,
                  isActive,
                  horizontal,
                );
                return (
                  <div key={language} className="px-5">
                    <button
                      onClick={() => handleLanguageClick(language)}
                      className={classes}
                    >
                      {language.toUpperCase()}
                    </button>
                  </div>
                );
              })}
          </div>
        </div>
      ) : (
        <div className="h-full">
          <div
            onMouseEnter={() => {
              onHover && onHover(true);
            }}
            onMouseLeave={() => {
              onHover && onHover(false);
            }}
            className={`group relative flex items-center cursor-pointer h-full transition-all ease-in duration-100 ${
              iconColor || ""
            }`}
          >
            <Earth size={20} />
            <div className="group-hover:block hidden absolute left-1/2 -translate-x-2/4 top-full bg-grey-900 font-plex text-sm leading-5 font-semibold">
              {languages &&
                languages.map((language, index) => {
                  const isActive = language === selectedLanguage;
                  const colorClasses = getLocaleColor(
                    isMobileOpen,
                    light,
                    isActive,
                    horizontal,
                  );

                  return (
                    <div
                      key={language}
                      className={`px-3.5 ${
                        index === 0
                          ? "pt-8 pb-4"
                          : index === languages.length - 1
                          ? "pt-4 pb-8"
                          : "py-4"
                      }`}
                    >
                      <button
                        onClick={() => handleLanguageClick(language)}
                        className={colorClasses}
                      >
                        {language.toUpperCase()}
                      </button>
                    </div>
                  );
                })}
            </div>
          </div>
        </div>
      )}
    </Fragment>
  ) : null;
};
