import React, { Fragment, useState, useEffect } from "react";
import { Search as SearchIcon } from "@carbon/icons-react";

type SearchProps = {
  shouldDoTransition: boolean;
  onClose?: () => void;
  onSearch?: (keyword: string) => void;
};

interface Props {
  faded?: boolean;
  onSearch: (keyword: string) => void;
  onHover?: (value: boolean) => void;
}

export const Search: React.FC<Props> = ({ onSearch, onHover, faded }) => {
  const [isSearchOpen, setIsSearchOpen] = useState(false);
  const [shouldDoTransition, setShouldDoTransition] = useState(false);
  const classes =
    "cursor-pointer transition-all ease-in duration-100 hover:text-grey-900";

  useEffect(() => {
    if (isSearchOpen) {
      setTimeout(() => {
        setShouldDoTransition(true);
      }, 75);
    }
  }, [isSearchOpen]);

  useEffect(() => {
    if (!shouldDoTransition) {
      setTimeout(() => {
        setIsSearchOpen(false);
      }, 75);
    }
  }, [shouldDoTransition]);

  return (
    <Fragment>
      <span
        onMouseEnter={() => onHover && onHover(true)}
        onMouseLeave={() => onHover && onHover(false)}
        onClick={() => setIsSearchOpen(true)}
        className={`${classes} ${faded ? "text-grey-400" : "text-grey-900"}`}
      >
        <SearchIcon size="20" />
      </span>
      {isSearchOpen && (
        <SearchContainer
          shouldDoTransition={shouldDoTransition}
          onSearch={onSearch}
          onClose={() => setShouldDoTransition(false)}
        />
      )}
    </Fragment>
  );
};

const SearchContainer: React.FC<SearchProps> = ({
  shouldDoTransition,
  onClose,
  onSearch,
}) => {
  return (
    <div className="fixed inset-0 z-50 flex items-start justify-center pt-16 sm:pt-24">
      <Backdrop
        shouldDoTransition={shouldDoTransition}
        onClose={() => onClose && onClose()}
      />
      <Input onSearch={onSearch} shouldDoTransition={shouldDoTransition} />
    </div>
  );
};

const Input: React.FC<SearchProps> = ({ shouldDoTransition, onSearch }) => {
  const handleSubmit = (e: React.KeyboardEvent<HTMLInputElement>) => {
    if (e.key === "Enter") {
      onSearch && onSearch(e.currentTarget.value);
    }
  };
  return (
    <div
      className={`relative w-full max-w-lg transform px-4 transition-all opacity-0 scale-0 ${
        shouldDoTransition ? "opacity-100 !scale-100" : ""
      }`}
    >
      <div className="overflow-hidden rounded-lg bg-white shadow-md">
        <div className="relative">
          <input
            onKeyDown={handleSubmit}
            className="block w-full appearance-none bg-transparent py-4 pl-4 pr-12 text-base text-slate-900 placeholder:text-slate-600 focus:outline-none sm:text-sm sm:leading-6"
            placeholder="Find anything..."
          />
          <SearchIcon
            size="20"
            className="absolute right-3.5 top-1/2 -translate-y-2/4"
          />
        </div>
      </div>
    </div>
  );
};

const Backdrop: React.FC<SearchProps> = ({ shouldDoTransition, onClose }) => {
  return (
    <div
      onClick={() => onClose && onClose()}
      className={`fixed inset-0 bg-slate-900/25 backdrop-blur transition-opacity opacity-0 ${
        shouldDoTransition ? "opacity-100" : ""
      }`}
    />
  );
};

